C----------------------------------------------------------------------
        subroutine ftgsdt(dd,mm,yy,status)

C       get the current date from the system

C       dd      i  day of the month (1-31)
C       mm      i  month of the year (1-12)
C       yy      i  last 2 digits of the year (1992 = 92, 2001 = 01)

        integer dd,mm,yy,status
        integer iarray(3)

        if (status .gt. 0)return

C       the following is the Sun Fortran routine to get the system date:
        call idate(iarray)
        
        dd=iarray(1)
        mm=iarray(2)
        yy=iarray(3)-(iarray(3)/100)*100

        end
